﻿* Encoding: UTF-8.

***************************************************************************
Read data: Insert data path in /File="\Rawdat.dat".

GET DATA  /TYPE=TXT
  /FILE="\Rawdat.dat"
  /ENCODING='Locale'
  /DELCASE=LINE
  /DELIMITERS="\t"
  /ARRANGEMENT=DELIMITED
  /FIRSTCASE=2
  /IMPORTCASE=ALL
  /VARIABLES=
  Subject F1.0
  Filter_Training F1.0
  BlockType F1.0
  BlockNr F2.0
  TrialNr F2.0
  Congruency F1.0
  PrimeArrow F1.0
  TargetArrow F1.0
  Response F1.0
  RT F4.0
  Rating F3.0
  RatingRT F4.0
  ErrType F1.0
  OK F1.0
  OK_N1 F3.0
  Prime.DurationError F1.0
  Prime.OnsetDelay F1.0
  Prime.OnsetTime F7.0
  Prime.OnsetToOnsetTime F2.0
  Mask1.DurationError F1.0
  Mask1.OnsetDelay F1.0
  Mask1.OnsetTime F7.0
  Mask1.OnsetToOnsetTime F2.0
  Mask2.DurationError F1.0
  Mask2.OnsetDelay F1.0
  Mask2.OnsetTime F7.0
  Mask2.OnsetToOnsetTime F2.0
  Blank.DurationError F1.0
  Blank.OnsetDelay F1.0
  Blank.OnsetTime F7.0
  Blank.OnsetToOnsetTime F2.0
  Target.DurationError F1.0
  Target.OnsetDelay F1.0
  Target.OnsetTime F7.0
  Target.OnsetToOnsetTime F4.0.
CACHE.
EXECUTE.
DATASET NAME Rawdat WINDOW=FRONT.

DATASET ACTIVATE Rawdat.

***************************************************************************
Variables description.

* Subject: individual number of the subject
* Filter_Training: 0 = practice blocks, 1 = experimental blocks (target response and rating; prime response for signal detection)
* BlockType: 1 = response to target, 2 = response to prime (signal detection)
* BlockNr: individual number of the block (1-11)
* TrialNr: individual number of the trial of the block (1-11)
* Congruency: congruency level of the current trial with 0 = incongruent, 1 = congruent
* PrimeArrow: pointing direction of the prime arrow with 1 = left, 2 = right
* TargetArrow: pointing direction of the target arrow with 1 = left, 2 = right
* Response: 1 = left, 2 = right response key pressed
* RT: target reaction time or prime reaction time (signal detection)
* Rating: 1 = conflict, 2 = guess conflict, 3 = guess no conflict, 4 = no conflict
* RatingRT: rating reaction time
* ErrType: type of error with 0 = no error, 1 = early response during fixation, 2 = commission error, 3 = omission error
* OK: accuracy with 0 = error, 1 = accurate
* OK_N1: accuracy of the preceding trial

* the following variables specifiy duration parameters of the used objects in eprime
* Prime.DurationError
  Prime.OnsetDelay F1.0
  Prime.OnsetTime F7.0
  Prime.OnsetToOnsetTime F2.0
  Mask1.DurationError F1.0
  Mask1.OnsetDelay F1.0
  Mask1.OnsetTime F7.0
  Mask1.OnsetToOnsetTime F2.0
  Mask2.DurationError F1.0
  Mask2.OnsetDelay F1.0
  Mask2.OnsetTime F7.0
  Mask2.OnsetToOnsetTime F2.0
  Blank.DurationError F1.0
  Blank.OnsetDelay F1.0
  Blank.OnsetTime F7.0
  Blank.OnsetToOnsetTime F2.0
  Target.DurationError F1.0
  Target.OnsetDelay F1.0
  Target.OnsetTime F7.0
  Target.OnsetToOnsetTime F4.0.



***************************************************************************
Prepare data.

* compute rating accuracy

IF (Congruency = 0 & (Rating = 1 | Rating = 2)) RatingAcc= 1.
IF (Congruency = 0 & (Rating = 3 | Rating = 4)) RatingAcc= 0.
IF (Congruency = 1 & (Rating = 1 | Rating = 2)) RatingAcc= 0.
IF (Congruency = 1 & (Rating = 3 | Rating = 4)) RatingAcc= 1.
FORMATS RatingAcc (f1.0).
EXECUTE.

* compute variables for the preceding trial

COMPUTE Congruency_N1=LAG(Congruency).
COMPUTE Rating_N1=LAG(Rating).
COMPUTE RatingAcc_N1=LAG(RatingAcc).
COMPUTE Target.OnsetTime_N1 = LAG(Target.OnsetTime).
COMPUTE RatingRT_N1 = LAG(RatingRT).
COMPUTE RT_N1 = LAG(RT).
FORMATS Congruency_N1 (f1.0).
FORMATS Rating_N1 (f1.0).
FORMATS RatingAcc_N1 (f1.0).
FORMATS Target.OnsetTime_N1 (f6.0).
FORMATS RatingRT_N1 (f6.0).
FORMATS RT_N1 (f6.0).
EXECUTE.

* check RT deviation of each participant and exclude participants (when 2 SDs above mean median; participants: 1, 46, 83).

USE ALL.
COMPUTE RTFilter=(RT ~= -99).
FORMATS RTFilter (f1.0).
FILTER BY RTFilter.
EXECUTE.

DATASET DECLARE RTDat.
AGGREGATE
  /OUTFILE='RTDat'
  /BREAK=Subject
  /RT_median=MEDIAN(RT)
  /NRTS=N.

DATASET ACTIVATE RTDat.

DELETE VARIABLES ZRT_median.
DESCRIPTIVES VARIABLES=RT_median
  /SAVE
  /STATISTICS=MEAN STDDEV MIN MAX.

USE ALL.
COMPUTE sbjctFilter=(ZRT_median <= 2).
FORMATS sbjctFilter (f1.0).
FILTER BY sbjctFilter.
EXECUTE.

DATASET CLOSE RTDat.

DATASET ACTIVATE Rawdat.

SELECT IF (Subject ~= 1 & Subject ~= 46 & Subject ~= 83).
EXECUTE.

* error rate by participant to check exclusion criteria (>25% errors; no participant)

CROSSTABS
  /TABLES=Subject BY OK
  /FORMAT=AVALUE TABLES
  /CELLS=ROW
  /COUNT ROUND CELL.


***************************************************************************
Filter for analyses on ratings and conflict detection.

DATASET ACTIVATE Rawdat.

* filter practice and signal detection block.

USE ALL.
COMPUTE preFilter=(Filter_Training  = 1 & BlockType = 1).
FORMATS preFilter (f1.0).
FILTER BY preFilter.
EXECUTE.

* filter error trials.

COMPUTE lightaccFilter=(OK = 1).
FORMATS lightaccFilter (f1.0).
EXECUTE.

FREQUENCIES VARIABLES=lightaccFilter.

* combine both filters

USE ALL.
COMPUTE lightconflictFilter=(preFilter  = 1 & lightaccFilter = 1).
FORMATS lightconflictFilter (f1.0).
FILTER BY lightconflictFilter.
EXECUTE.


*********
Conflict experience: rating frequencies.

DATASET ACTIVATE Rawdat.

* filter practice, signal detection and errors in trial n.

USE ALL.
FILTER BY lightconflictFilter.
EXECUTE.

* aggregate ratings.

DATASET DECLARE RatingDat.
AGGREGATE
  /OUTFILE='Ratingdat'
  /BREAK=Subject Rating Congruency
  /NRating=N.

DATASET ACTIVATE RatingDat.

SORT CASES BY Subject Rating Congruency.
CASESTOVARS
  /ID=Subject
  /INDEX= Rating Congruency
  /GROUPBY=VARIABLE.

* replace missing values (no rating in this condition) with 0.

RECODE NRating.1.0 NRating.1.1 NRating.2.0 NRating.2.1 NRating.3.0 NRating.3.1 NRating.4.0 NRating.4.1 (MISSING=0).
EXECUTE.

* compute percentages of ratings.

COMPUTE NRatings = NRating.1.0 + NRating.1.1 + NRating.2.0 + NRating.2.1 + NRating.3.0 + NRating.3.1 + NRating.4.0 + NRating.4.1.
FORMATS NRatings (f3.0).
EXECUTE.

COMPUTE PRating.1.0 = (NRating.1.0 / NRatings) *100.
COMPUTE PRating.1.1 = (NRating.1.1 / NRatings) *100.
COMPUTE PRating.2.0 = (NRating.2.0 / NRatings) *100.
COMPUTE PRating.2.1 = (NRating.2.1 / NRatings) *100.
COMPUTE PRating.3.0 = (NRating.3.0 / NRatings) *100.
COMPUTE PRating.3.1 = (NRating.3.1 / NRatings) *100.
COMPUTE PRating.4.0 = (NRating.4.0 / NRatings) *100.
COMPUTE PRating.4.1 = (NRating.4.1 / NRatings) *100.
EXECUTE.

* compute paired-samples t-tests to get 95% CIs of paired differences for plots.

T-TEST PAIRS=PRating.1.0 PRating.2.0 PRating.3.0 PRating.4.0 WITH PRating.1.1 PRating.2.1 PRating.3.1 PRating.4.1 (PAIRED)
  /CRITERIA=CI(.9500)
  /MISSING=ANALYSIS.


*********
Compute variable with dichotomized ratings and a variable for detection accuracy.

DATASET ACTIVATE Rawdat.

* compute dichotomized ratings (include all four or just the two extreme ratings).

IF (Rating = 1 | Rating = 2) dichRating = 1.
IF (Rating = 3 | Rating = 4) dichRating = 2.
FORMATS dichRating (f1.0).
EXECUTE.

* compute detection accuracy
* 1 = hits (incongruent trial > incongruent rating) 
* 2 = misses (incongruent trial > congruent rating)
* 3 = correct rejections (congruent trial > congruent rating)
* 4 = false alarms  (congruent trial > incongruent rating).

COMPUTE detection = 0.
EXECUTE.

IF (Congruency = 0 & (Rating = 1 | Rating = 2)) detection = 1.
IF (Congruency = 0 & (Rating = 3 | Rating = 4)) detection = 2.
IF (Congruency = 1 & (Rating = 1 | Rating = 2)) detection = 4.
IF (Congruency = 1 & (Rating = 3 | Rating = 4)) detection = 3.
FORMATS detection (f1.0).
EXECUTE.

* compute filter for subjects with less than 10 observations in one of the experimental cells for adaptation analyses (see below).

USE ALL.
COMPUTE sbjctFilter = 1.
FORMATS sbjctFilter (f1.0).
EXECUTE.

IF (Subject = 2 | Subject = 4 | Subject = 13 | Subject = 22 | 
Subject = 29 | Subject = 32 | Subject = 33 | Subject = 35 | 
Subject = 36 | Subject = 41 | Subject = 43 | Subject = 44 | 
Subject = 45 | Subject = 50 | Subject = 54 | Subject = 67 | 
Subject = 68 | Subject = 74 | Subject = 77 | Subject = 78 | 
Subject = 80 | Subject = 81 | Subject = 84) sbjctFilter = 0.
EXECUTE.


*********
Conflict experience: conflict-d' and conflict-c.

DATASET ACTIVATE Rawdat.

* filtering practice, signal detection and errors in trial n.

USE ALL.
FILTER BY lightconflictFilter.

* aggregate detection data.

DATASET DECLARE DetectionDat.
AGGREGATE
  /OUTFILE='DetectionDat'
  /BREAK=Subject sbjctFilter detection
  /ND=N.

DATASET ACTIVATE DetectionDat.

SORT CASES BY Subject sbjctFilter detection.
CASESTOVARS
  /ID=Subject sbjctFilter
  /INDEX=detection
  /GROUPBY=VARIABLE.

* replace missing values (empty cells) with 0.

RECODE ND.1 ND.2 ND.3 ND.4 (MISSING=0).
EXECUTE.

* compute hit rates and false alarm rates.

COMPUTE HR=((ND.1)/(ND.1 + ND.2)).
COMPUTE FAR=((ND.4)/(ND.4 + ND.3)).
EXECUTE.

* number of participants with at least one correction of HR or FAR.

IF(HR = 0 | HR = 1 | FAR = 0 | FAR = 1) correction = 1.
FORMATS correction (f1.0).
EXECUTE.

FREQUENCIES VARIABLES=correction
  /ORDER=ANALYSIS.

DELETE VARIABLES correction.

* correct values of 0 and 1 to .05 and .95.

IF (HR=0) HR = 0.05.
IF (HR=1) HR = 0.95.
IF (FAR=0) FAR = 0.05.
IF (FAR=1) FAR = 0.95.
EXECUTE.

* compute z-values of hit rates and false alarm rates

COMPUTE z_HR=IDF.NORMAL(HR,0,1).
COMPUTE z_FAR=IDF.NORMAL(FAR,0,1).
EXECUTE.

*compute conflict-d' and conflict-c.

COMPUTE conflict_d = z_HR - z_FAR.
COMPUTE conflict_c= -0.5*(z_HR + z_FAR).
EXECUTE.

* test condlict-d' and conflict-c in a one sample t-tests against 0.

T-TEST
  /TESTVAL=0
  /MISSING=ANALYSIS
  /VARIABLES=conflict_d conflict_c
  /CRITERIA=CI(.95).

* filter subjects with less than 10 observations in one of the experimental cells for adaptation analyses (see below).

FILTER BY sbjctFilter.

* test condlict-d' and conflict-c in  one sample t-tests against 0 with filtered sample.

T-TEST
  /TESTVAL=0
  /MISSING=ANALYSIS
  /VARIABLES=conflict_d conflict_c
  /CRITERIA=CI(.95).



***************************************************************************
Filter for analyses on conflict strength and conflict adaptation.

DATASET ACTIVATE Rawdat.

* delete first trial of each block because of sequential analyses.

SELECT IF (TrialNr > 1).
EXECUTE.

FILTER BY lightconflictFilter.

FREQUENCIES VARIABLES=OK_N1.

* filter practice, signal detection block, erroneous trials and trials that follow an error.

USE ALL.
COMPUTE conflictFilter=(lightconflictFilter  = 1 & OK_N1 = 1).
FORMATS conflictFilter (f1.0).
FILTER BY conflictFilter.
EXECUTE.


*********
Conflict strength and the experience of conflict.

DATASET ACTIVATE Rawdat.

* filter practice, signal detection erroneous trials and trials that follow an error.

USE ALL.
FILTER BY conflictFilter.

* compute linear regression coefficients separately for each participant and write them in new data set (Pfister, Schwarz, Carson, & Janczyk, 2013).

SORT CASES  BY Subject.
SPLIT FILE LAYERED BY Subject.

DATASET DECLARE SlopesDat.

* Define the request to the Output Management System (OMS), compute linear regression, and send information to new data sheet.

OMS
  /SELECT TABLES
  /IF COMMANDS=['Regression'] SUBTYPES=['Coefficients']
  /DESTINATION FORMAT=SAV NUMBERED=TableNumber_
   OUTFILE='SlopesDat' VIEWER=YES.

REGRESSION
  /DESCRIPTIVES MEAN STDDEV CORR SIG N
  /MISSING LISTWISE
  /STATISTICS COEFF OUTS R ANOVA
  /CRITERIA=PIN(.05) POUT(.10)
  /NOORIGIN 
  /DEPENDENT Rating
  /METHOD=ENTER RT.

OMSEND.

SPLIT FILE OFF.
SORT CASES  BY Subject BlockNr TrialNr.

DATASET ACTIVATE SlopesDat.

* clean data sheet

DELETE VARIABLES TableNumber_ TO Label_.
DELETE VARIABLES Standardfehler TO Sig.
DELETE VARIABLES Var2.

SELECT IF (Var3 = "RT").
EXECUTE.

ALTER TYPE  Var1(F2.0).
FORMATS  Var1(F2.0).
EXECUTE.

COMPUTE subject = Var1.
FORMATS  subject(F2.0).
EXECUTE.

DELETE VARIABLES Var1 TO Var3.

* compute filter for subjects with less than 10 observations in one of the experimental cells for adaptation analyses (see below).

USE ALL.
COMPUTE sbjctFilter = 1.
FORMATS sbjctFilter (f1.0).
EXECUTE.

IF (Subject = 2 | Subject = 4 | Subject = 13 | Subject = 22 | 
Subject = 29 | Subject = 32 | Subject = 33 | Subject = 35 | 
Subject = 36 | Subject = 41 | Subject = 43 | Subject = 44 | 
Subject = 45 | Subject = 50 | Subject = 54 | Subject = 67 | 
Subject = 68 | Subject = 74 | Subject = 77 | Subject = 78 | 
Subject = 80 | Subject = 81 | Subject = 84) sbjctFilter = 0.
EXECUTE.

FILTER BY sbjctFilter.

* compute one-sample t-test.

T-TEST
  /TESTVAL=0
  /MISSING=ANALYSIS
  /VARIABLES=RegressionskoeffizientB
  /CRITERIA=CI(.95).


*********
The experience of conflict and adaptation: RT.

DATASET ACTIVATE Rawdat.

* mean rating RT and starting RT.

USE ALL.
COMPUTE timeFilter=(conflictFilter  = 1  & sbjctFilter = 1).
FORMATS timeFilter (f1.0).
FILTER BY timeFilter.
EXECUTE.

COMPUTE StartingRT = Prime.OnsetTime - Target.OnsetTime_N1 - 1000 - RatingRT_N1 - RT_N1.
EXECUTE.

DESCRIPTIVES VARIABLES=RatingRT StartingRT
  /STATISTICS=MEAN STDDEV SEMEAN.

* filter practice, signal detection block, erroneous trials and trials that follow an error.

USE ALL.
FILTER BY conflictFilter.

* aggregate RT data.

DATASET DECLARE RTDat.
AGGREGATE
  /OUTFILE='RTDat'
  /BREAK=Subject Congruency Congruency_N1 RatingACC_N1
  /RT_mean=MEAN(RT)
  /NRTS=N.

DATASET ACTIVATE RTDat.

SORT CASES BY Subject Congruency Congruency_N1 RatingACC_N1.
CASESTOVARS
  /ID=Subject
  /INDEX=Congruency Congruency_N1 RatingACC_N1
  /GROUPBY=VARIABLE.

* filter subjects will less than 10 observations in any of the experimental cells.

USE ALL.
COMPUTE sbjctFilter=(NRTS.0.0.0 >= 10 & NRTS.0.0.1  >= 10 & NRTS.0.1.0  >= 10 & NRTS.0.1.1 >= 10 & NRTS.1.0.0 >= 10 & NRTS.1.0.1  >= 10 & NRTS.1.1.0  >= 10 & NRTS.1.1.1 >= 10).
FORMATS sbjctFilter (f1.0).
FILTER BY sbjctFilter.
EXECUTE.

* ANOVA

GLM RT_mean.0.0.0 RT_mean.0.0.1 RT_mean.0.1.0 RT_mean.0.1.1 RT_mean.1.0.0 RT_mean.1.0.1 
    RT_mean.1.1.0 RT_mean.1.1.1
  /WSFACTOR=congruency 2 Polynomial congruencyN1 2 Polynomial RatingACCN1 2 Polynomial 
  /METHOD=SSTYPE(3)
  /PLOT=PROFILE(congruency congruencyN1*congruency*RatingACCN1)
  /PRINT=DESCRIPTIVE ETASQ 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=congruency congruencyN1 RatingACCN1 congruency*congruencyN1 congruency*RatingACCN1 
    congruencyN1*RatingACCN1 congruency*congruencyN1*RatingACCN1.

* compute congruency effect and paired-samples t-tests to get 96% CIs of paired differences for plots.

T-TEST PAIRS=RT_mean.0.1.0 RT_mean.0.1.1 RT_mean.0.0.0 RT_mean.0.0.1 WITH RT_mean.1.1.0 RT_mean.1.1.1 RT_mean.1.0.0 RT_mean.1.0.1 (PAIRED)
  /CRITERIA=CI(.9500)
  /MISSING=ANALYSIS.

COMPUTE RT.1.0 = RT_mean.0.1.0 - RT_mean.1.1.0.
COMPUTE RT.1.1 = RT_mean.0.1.1 - RT_mean.1.1.1.
COMPUTE RT.0.0 = RT_mean.0.0.0 - RT_mean.1.0.0.
COMPUTE RT.0.1 = RT_mean.0.0.1 - RT_mean.1.0.1.
EXECUTE.

T-TEST PAIRS=RT.1.1 RT.1.0 WITH RT.0.1 RT.0.0 (PAIRED)
  /CRITERIA=CI(.9500)
  /MISSING=ANALYSIS.


*********
The experience of conflict and adaptation: PE.

DATASET ACTIVATE Rawdat.

* filtering practice, signal detection, early responses and omission errors in trial n and all trials that follow errors.

USE ALL.
COMPUTE PEfilter=(preFilter = 1 & (ErrType = 0 | ErrType = 2) & OK_N1 = 1).
FORMATS PEfilter (f1.0).
FILTER BY PEfilter.
EXECUTE.

* aggregate PE data.

DATASET DECLARE PEDat.
AGGREGATE
  /OUTFILE='PEDat'
  /BREAK=Subject Congruency Congruency_N1 RatingAcc_N1 OK
  /NT=N.

DATASET ACTIVATE PEDat.

SORT CASES BY Subject Congruency Congruency_N1 RatingAcc_N1 OK.
CASESTOVARS
  /ID=Subject
  /INDEX=Congruency Congruency_N1 RatingAcc_N1 OK
  /GROUPBY=VARIABLE.

* replace missing values (empty cells) with 0.

RECODE NT.0.0.0.0 NT.0.0.0.1 NT.0.0.1.0 NT.0.0.1.1 NT.0.1.0.0 NT.0.1.0.1 NT.0.1.1.0 NT.0.1.1.1 
    NT.1.0.0.0 NT.1.0.0.1 NT.1.0.1.0 NT.1.0.1.1 NT.1.1.0.0 NT.1.1.0.1 NT.1.1.1.0 NT.1.1.1.1 (SYSMIS=0).
EXECUTE.

* filter subjects will less than 10 observations in any of the experimental cells.

USE ALL.
COMPUTE sbjctFilter=(NT.0.0.0.1 >= 10 & NT.0.0.1.1 >= 10 & NT.0.1.0.1 >= 10 & NT.0.1.1.1 >= 10 & NT.1.0.0.1 >= 10 & NT.1.0.1.1 >= 10 & NT.1.1.0.1 >= 10 & NT.1.1.1.1 >= 10).
FORMATS sbjctFilter (f1.0).
FILTER BY sbjctFilter.
EXECUTE.

* compute PEs for each experimental cell.

COMPUTE PE.0.0.0 =  (NT.0.0.0.0 * 100) / (NT.0.0.0.0 + NT.0.0.0.1).
COMPUTE PE.0.0.1 =  (NT.0.0.1.0 * 100) / (NT.0.0.1.0 + NT.0.0.1.1).
COMPUTE PE.0.1.0 =  (NT.0.1.0.0 * 100) / (NT.0.1.0.0 + NT.0.1.0.1).
COMPUTE PE.0.1.1 =  (NT.0.1.1.0 * 100) / (NT.0.1.1.0 + NT.0.1.1.1).
COMPUTE PE.1.0.0 =  (NT.1.0.0.0 * 100) / (NT.1.0.0.0 + NT.1.0.0.1).
COMPUTE PE.1.0.1 =  (NT.1.0.1.0 * 100) / (NT.1.0.1.0 + NT.1.0.1.1).
COMPUTE PE.1.1.0 =  (NT.1.1.0.0 * 100) / (NT.1.1.0.0 + NT.1.1.0.1).
COMPUTE PE.1.1.1 =  (NT.1.1.1.0 * 100) / (NT.1.1.1.0 + NT.1.1.1.1).
EXECUTE.

* ANOVA.

GLM PE.0.0.0 PE.0.0.1 PE.0.1.0 PE.0.1.1 PE.1.0.0 PE.1.0.1 PE.1.1.0 PE.1.1.1
  /WSFACTOR=congruency 2 Polynomial congruencyN1 2 Polynomial RatingACCN1 2 Polynomial 
  /METHOD=SSTYPE(3)
  /PLOT=PROFILE(congruency congruencyN1*congruency*RatingACCN1)
  /PRINT=DESCRIPTIVE ETASQ 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=congruency congruencyN1 RatingACCN1 congruency*congruencyN1 congruency*RatingACCN1 
    congruencyN1*RatingACCN1 congruency*congruencyN1*RatingACCN1.

* compute congruency effects and paired-samples t-tests to get CIs of paired differences for plots.

T-TEST PAIRS=PE.0.1.0 PE.0.1.1 PE.0.0.0 PE.0.0.1 WITH PE.1.1.0 PE.1.1.1 PE.1.0.0 PE.1.0.1 (PAIRED)
  /CRITERIA=CI(.9500)
  /MISSING=ANALYSIS.

COMPUTE PE.1.0 = PE.0.1.0 - PE.1.1.0.
COMPUTE PE.1.1 = PE.0.1.1 - PE.1.1.1.
COMPUTE PE.0.0 = PE.0.0.0 - PE.1.0.0.
COMPUTE PE.0.1 = PE.0.0.1 - PE.1.0.1.
EXECUTE.

T-TEST PAIRS=PE.1.1 PE.1.0 WITH PE.0.1 PE.0.0 (PAIRED)
  /CRITERIA=CI(.9500)
  /MISSING=ANALYSIS.



***************************************************************************
Filter for analyses on prime visibility.

USE ALL.
DATASET ACTIVATE Rawdat.

* select signal detection block.

USE ALL.
COMPUTE preSDfilter=(Blocktype = 2).
FORMATS preSDfilter (f1.0).
FILTER BY preSDfilter.
EXECUTE.

* frequency of omissions and early responses.

FREQUENCIES VARIABLES=ErrType.

* select signal detection and filter omissions and early responses.

USE ALL.
COMPUTE SDfilter=((ErrType = 0 |  ErrType = 2) & preSDfilter = 1).
FORMATS SDfilter (f1.0).
FILTER BY SDfilter.
EXECUTE.

*********
Prime Visibility: visibility-d' and visibility-c.

DATASET ACTIVATE Rawdat.

* select signal detection and filter omissions and early responses.

FILTER BY SDfilter.

* frequency of left and right responses.

FREQUENCIES VARIABLES=Response.

* compute detection accuracy
* 1 = hits (left-pointing prime > left response) 
* 2 = misses (left-pointing prime > right response) 
* 3 = correct rejections (right-pointing prime > right response) 
* 4 = false alarms (right-pointing prime > left response).

IF (PrimeArrow = 1 & Response = 1) detection_Prime = 1.
IF (PrimeArrow = 1 & Response = 2) detection_Prime = 2.
IF (PrimeArrow = 2 & Response = 2) detection_Prime = 3.
IF (PrimeArrow = 2 & Response = 1) detection_Prime = 4.
FORMATS detection_Prime (f1.0).
EXECUTE.

* aggregate detection data.

DATASET DECLARE PrimeVisibilityDat.
AGGREGATE
  /OUTFILE='PrimeVisibilityDat'
  /BREAK=Subject sbjctFilter detection_Prime
  /ND=N.

DATASET ACTIVATE PrimeVisibilityDat.

SORT CASES BY subject detection_Prime.
CASESTOVARS
  /ID=subject sbjctFilter
  /INDEX= detection_Prime
  /GROUPBY=VARIABLE.

* replace missing values (empty cells) with 0.

RECODE ND.1 ND.2 ND.3 ND.4 (MISSING=0).
EXECUTE.

*compute hit rates and false alarm rates.

COMPUTE HR=((ND.1)/(ND.1 + ND.2)).
COMPUTE FAR=((ND.4)/(ND.4 + ND.3)).
EXECUTE.

* number of participants with at least one correction of HR or FAR.

IF(HR = 0 | HR = 1 | FAR = 0 | FAR = 1) correction = 1.
FORMATS correction (f1.0).
EXECUTE.

FREQUENCIES VARIABLES=correction
  /ORDER=ANALYSIS.

DELETE VARIABLES correction.

* correct values of 0 and 1 to .05 and .95.

IF (HR=0) HR = 0.05.
IF (HR=1) HR = 0.95.
IF (FAR=0) FAR = 0.05.
IF (FAR=1) FAR = 0.95.
EXECUTE.

* compute z-values of hit rates and false alarm rates.

COMPUTE z_HR=IDF.NORMAL(HR,0,1).
COMPUTE z_FAR=IDF.NORMAL(FAR,0,1).
EXECUTE.

*compute visibility-d' and visibility-c.

COMPUTE visibility_d = z_HR - z_FAR.
COMPUTE visibility_c = -0.5*(z_HR + z_FAR).
EXECUTE.

* filter for subjects with less than 10 observations in one of the experimental cells for adaptation analyses (see above).

FILTER BY sbjctFilter.

* test condlict-d' and conflict-c in one sample t-tests against 0.

T-TEST
  /TESTVAL=0
  /MISSING=ANALYSIS
  /VARIABLES=visibility_d visibility_c
  /CRITERIA=CI(.95).


*********
Prime Visibility: Linear regression of visibility-d' and conflict-d'.

DATASET ACTIVATE PrimeVisibilityDat.

* match variables.

MATCH FILES /FILE=*
  /RENAME (FAR HR ND.1 ND.2 ND.3 ND.4 sbjctFilter z_FAR z_HR = d0 d1 d2 d3 d4 d5 d6 d7 d8) 
  /FILE='DetectionDat'
  /RENAME (FAR HR ND.1 ND.2 ND.3 ND.4 Subject z_FAR z_HR = d9 d10 d11 d12 d13 d14 d15 d16 
    d17) 
  /DROP= d0 d1 d2 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12 d13 d14 d15 d16 d17.
EXECUTE.

FORMATS visibility_d (F8.6).
FORMATS conflict_d (F8.6).

* filter for subjects with less than 10 observations in one of the experimental cells for adaptation analyses (see above).

FILTER BY sbjctFilter.

* linear regression with visibility-d' as predictor and conflict-d' as dependent variable.

REGRESSION
  /DESCRIPTIVES MEAN STDDEV CORR SIG N
  /MISSING LISTWISE
  /STATISTICS COEFF OUTS R ANOVA
  /CRITERIA=PIN(.05) POUT(.10)
  /NOORIGIN 
  /DEPENDENT conflict_d
  /METHOD=ENTER visibility_d.

*********
Prime Visibility: Correlation of visibility-d' and adaptation effects.

DATASET ACTIVATE PrimeVisibilityDat.

* match variables.

MATCH FILES /FILE=*
  /FILE='RTDat'
  /RENAME (NRTS.0.0.0 NRTS.0.0.1 NRTS.0.1.0 NRTS.0.1.1 NRTS.1.0.0 NRTS.1.0.1 NRTS.1.1.0 NRTS.1.1.1 
    RT.0.0 RT.0.1 RT.1.0 RT.1.1 sbjctFilter Subject = d0 d1 d2 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12 d13) 
  /DROP= d0 d1 d2 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12 d13.
EXECUTE.

* compute adaptation effects (RT_mean.CurrentCongruency.PrecedingCongruency.RatingAccuracy)

COMPUTE RT_adaptation_correct = (RT_mean.0.1.1 - RT_mean.1.1.1) -  (RT_mean.0.0.1 - RT_mean.1.0.1). 
COMPUTE RT_adaptation_incorrect = (RT_mean.0.1.0 - RT_mean.1.1.0) -  (RT_mean.0.0.0 - RT_mean.1.0.0). 
EXECUTE.

* filter for subjects with less than 10 observations in one of the experimental cells for adaptation analyses (see above).

FILTER BY sbjctFilter.

* Pearson correlation (Linear regression to extract t-value easily).

REGRESSION
  /DESCRIPTIVES MEAN STDDEV CORR SIG N
  /MISSING LISTWISE
  /STATISTICS COEFF OUTS R ANOVA
  /CRITERIA=PIN(.05) POUT(.10)
  /NOORIGIN 
  /DEPENDENT RT_adaptation_correct
  /METHOD=ENTER visibility_d.

REGRESSION
  /DESCRIPTIVES MEAN STDDEV CORR SIG N
  /MISSING LISTWISE
  /STATISTICS COEFF OUTS R ANOVA
  /CRITERIA=PIN(.05) POUT(.10)
  /NOORIGIN 
  /DEPENDENT RT_adaptation_incorrect
  /METHOD=ENTER visibility_d.


* Done. Close all data sets.

DATASET CLOSE ALL.

